==> testpulse_uploader-0.0.1-py3-none-any.whl: uploader/upload.py <==
#!/usr/bin/env python3

import argparse
from pathlib import Path
import re
from typing import Optional, Pattern

from uploader.sender import send_test_results
from uploader.zipper import find_files, zip_files


def regex_pattern(regex: str) -> Optional[Pattern[str]]:
    if not regex:
        return None

    try:
        return re.compile(regex)
    except re.error:
        msg = f"String '{regex}' is not valid regex pattern"
        raise argparse.ArgumentTypeError(msg)


def create_parser() -> argparse.ArgumentParser:
    """Parse known test runner arguments.

    Returns:
        argparse.Namespace: namespace of parsed argument values
    """
    parser = argparse.ArgumentParser(
                    prog='upload.py',
                    description='Upload test results for futher processing',
                    epilog='testpulse-io')

    parser.add_argument(
        "-c",
        "--commit",
        type=str,
        default="master",
        help="Commit where the tests run on",
    )

    parser.add_argument(
        "-tr",
        "--test-results-regex",
        required=True,
        help="Regex pattern to find test results XML files",
        type=regex_pattern,
    )

    parser.add_argument(
        "-p",
        "--port",
        default=8080,
        type=int,
        help="Port used to communicate with testpulse-receiver",
    )

    return parser


def run(args: argparse.Namespace) -> None:
    root = Path().resolve()
    selected_files = find_files(args.test_results_regex, root=root)
    zip_file_name = zip_files(files_list=selected_files, root=root)
    req = send_test_results(Path(zip_file_name), port=args.port)

    if req is True:
        print(f'Saved zip file in {zip_file_name}')


def main():
    parser = create_parser()
    args = parser.parse_args()
    run(args=args)


main()

==> testpulse_uploader-0.0.3-py3-none-any.whl: uploader/upload.py <==
#!/usr/bin/env python3

import argparse
from pathlib import Path
import re
from typing import Optional, Pattern
from uploader.authentication import authenticate

from uploader.sender import send_test_results
from uploader.zipper import find_files, zip_files


def regex_pattern(regex: str) -> Optional[Pattern[str]]:
    if not regex:
        return None

    try:
        return re.compile(regex)
    except re.error:
        msg = f"String '{regex}' is not valid regex pattern"
        raise argparse.ArgumentTypeError(msg)


def create_parser() -> argparse.ArgumentParser:
    """Parse known test runner arguments.

    Returns:
        argparse.Namespace: namespace of parsed argument values
    """
    parser = argparse.ArgumentParser(
                    prog='upload.py',
                    description='Upload test results for futher processing',
                    epilog='testpulse-io')

    parser.add_argument(
        "-c",
        "--commit",
        type=str,
        default="master",
        help="Commit where the tests run on",
    )

    parser.add_argument(
        "-tr",
        "--test-results-regex",
        required=True,
        help="Regex pattern to find test results XML files",
        type=regex_pattern,
    )

    parser.add_argument(
        "-p",
        "--port",
        default=8080,
        type=int,
        help="Port used to communicate with testpulse-receiver",
    )

    parser.add_argument(
        "-l",
        "--localhost",
        help="Regex pattern to find test results XML files",
        action='store_true'
    )

    return parser


def run(args: argparse.Namespace) -> None:
    root = Path().resolve()
    print('Authenticating...')
    authenticate()
    print('Authenticated successfully.')

    print('Finding files and zipping...')
    selected_files = find_files(args.test_results_regex, root=root)

    zip_file_name = zip_files(files_list=selected_files, root=root)
    if zip_file_name is None:
        return

    print(f'Saved zip file in {zip_file_name}.')

    print('Uploading to our backend server...')
    req = send_test_results(Path(zip_file_name), localhost=args.localhost)

    if req is True:
        print('Upload was successful!')


def main():
    parser = create_parser()
    args = parser.parse_args()
    run(args=args)


if __name__ == '__main__':
    main()
